@@ -22,8 +22,10 @@ class FastReadCounter(object):
 
 class SymbolType:
     Stock = 'Stock'
-    Futures = 'Futures'
-    Options = 'Options'
+    FuturesStock = 'FuturesStock'
+    OptionsStock = 'OptionsStock'
+    FuturesIndex = 'FuturesIndex'
+    OptionsIndex = 'OptionsIndex'
 
 
 class LogLevel:
