@@ -11,7 +11,7 @@ from .remote_indicator_evaluator import *
 
 
 def get_date_format(timestamp: str):
-    if timestamp.find("Z"):
+    if timestamp.find("Z") > 0:
         return "%Y-%m-%dT%H:%M:%SZ"
     else:
         return "%Y-%m-%dT%H:%M:%S"
